let websocket = null

function initSocketEevent(options) {
  // 连接发生错误的回调方法
  websocket.onerror = function() {
    console.log('socket connect with error !')
    options.onerror && options.onerror('WebSocket连接出现了问题，请稍后重试！！！')
  }

  // 连接成功建立的回调方法
  websocket.onopen = function() {
    console.log('socket is open !')
    options.onopen && options.onopen()
  }

  // 接收到消息的回调方法
  websocket.onmessage = function(event) {
    console.log(event.data)
    options.onmessage && options.onmessage(JSON.parse(event.data))
  }

  // 连接关闭的回调方法
  websocket.onclose = function() {
    console.log('socket is closed !')
    options.onclose && options.onclose()
  }

  // 监听窗口关闭事件，当窗口关闭时，主动去关闭websocket连接，防止连接还没断开就关闭窗口，server端会抛异常。
  window.onbeforeunload = function() {
    websocket && websocket.close()
  }
}

export function createSocket(options, error) {
  // 判断当前浏览器是否支持WebSocket
  if (!('WebSocket' in window)) return error && error('当前浏览器不支持WebSocket，连接已关闭！！！')
  // 单例
  if (websocket) return
  websocket = new WebSocket(process.env.VUE_APP_SOCKET_SERVER)
  initSocketEevent(options)
}

// 关闭连接
export function closeWebSocket() {
  websocket && websocket.close()
  websocket = null
}
